class PlanetInput:
    def __init__(self, P, r, e, a=0.1, omega=0.0):
        self.P = P
        self.a = a
        self.r = r
        self.e = e
        self.omega = omega